package com.ashokit.ticketbooking.service;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ashokit.ticketbooking.dao.TicketDao;
import com.ashokit.ticketbooking.model.Ticket;

@Service

//This annotation tells the spring boot as business logic layer 
// So that Transaction Mgmt , Logging etc will be handled by framework itself


public class TicketService {
	
	//We need to invoke TicketDao 
	
	@Autowired
	private TicketDao ticketDao; //TicketDao ticketDao=ioc.getTicketDao();
	
	//Create Ticket
	
	public Ticket CreateTicket(Ticket inputObj) {
		return ticketDao.save(inputObj);
		//save ==> insert the data to table
		//inputObj.getTicketId == null 
	}
	
	//Retrive All Tickets
	
	public Iterable<Ticket> getAllTickets(){
		
		return ticketDao.findAll();
		
		//findAll ==> select * from tbl_ticket ;
		//Resultset will be converted into Iterable<Ticket>
	}
	
	
	//Retrive Single Ticket
	
	public Ticket getTicket(Integer ticketId) {
		
		return ticketDao.findById(ticketId).
											orElse(new Ticket());
		
		//findById ==> select * from tbl_ticket where ticket_id=ticketId
		//Resultset will be converted into Ticket Object
		//Ticket.getPassengerName() ==> null , if we dont include optional ==> Ticket.getPassengerName()  ==> NLP
		
		
	}
	
	//Update Ticket
	
	public Ticket updateTicket(Integer ticketId,String newEmail) {
		
		//save ==> This is API which will update the ticket object
		
		Ticket dbTicketObj=getTicket(ticketId); //dbTicketObj.getTicketId != null
		
		dbTicketObj.setEmail(newEmail);
		
		return ticketDao.save(dbTicketObj);
		//save ==> update tbl_ticket set email=newEmail where ticket_id=ticketId
		
	}
	
	
	//Delete Ticket
	public void deleteTicket(Integer ticketId) {
		
		ticketDao.deleteById(ticketId);
		
		//deleteById ==> delete from tbl_ticket where ticket_id=ticketId
		
	}
	
	
	

}
